==> haskell-lens-action-0.2.6-204-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-5Gir6TYQnxX5Pl3JD6NndG
key:                  lens-action-0.2.6-5Gir6TYQnxX5Pl3JD6NndG
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  ac0069b83915bbec1e9b3ce6819e0726
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-5Gir6TYQnxX5Pl3JD6NndG
depends:
    base-4.16.4.0 comonad-5.0.8-KDCuTFA2mjoED8eK6rT9Kd
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    lens-5.2.3-I3ec5MPKyg91QrvRMYPpyk mtl-2.2.2
    profunctors-5.6.2-GShwRP90Jtv64Kn3eksX1P
    semigroupoids-6.0.0.1-BsXeKcgZXpkECLqwp0kL5O transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-action-0.2.6-206-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-7FRvJQn2kGq2iz4fDMaWfU
key:                  lens-action-0.2.6-7FRvJQn2kGq2iz4fDMaWfU
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  05a8e283e14bacfeb95afa3aa6ab19af
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-7FRvJQn2kGq2iz4fDMaWfU
depends:
    base-4.16.4.0 comonad-5.0.8-KLcF2ODo2fK3AiiNSFU4oD
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    lens-5.2.3-Ay8F9EUtjnE9PU0we5yejR mtl-2.2.2
    profunctors-5.6.2-EO6U9ftGsuH5QejRbsXCU2
    semigroupoids-6.0.0.1-CiKv0Fr9KpC7HcwUSK24F2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
